<?php

class MmVocabSyncService {

  /**
   * Fetches an associative array of categories and keywords.
   *
   * @return array
   *   An associative array of categories and keywords.
   */
  public static function fetch() {
    $categories = array();
    $page = 0;
    $last = 1;
    while ($page < $last) {
      $page++;
      $path = mm_query_url("keywords.json?page=$page");
      $request = drupal_http_request($path);
      $result = json_decode($request->data);
      $last = $result->meta->total_pages;
      foreach ($result->keywords as $keyword) {
        $categories[$keyword->category][] = $keyword;
      }
    }
    return $categories;
  }

  /**
   * Create and synchronize vocabularies.
   */
  public static function sync() {
    $categories = MmVocabSyncService::fetch();
    foreach ($categories as $category => $keywords) {

      // Create the vocabulary if it doesn't exist.
      $machine_name = 'mm_' . $category;
      $plural = ucfirst($category) . 's';
      $vocab = taxonomy_vocabulary_machine_name_load($machine_name);
      if (!$vocab) {
        $vocab = new stdClass();
        MmVocabSyncService::addDisplayName($machine_name);
      }

      // Update and save vocabulary.
      $vocab->name = $plural . ' (Media Magnet)';
      $vocab->machine_name = $machine_name;
      $vocab->description = $plural . ' keywords from Media Magnet';
      $vocab->hierarchy = 0;
      $vocab->module = 'mm';
      $vocab->weight = 0;
      taxonomy_vocabulary_save($vocab);

      // Create each term if it doesn't exist.
      foreach ($keywords as $keyword) {
        $term = taxonomy_get_term_by_name($keyword->name, $machine_name);
        if (!$term) {
          $term = new stdClass();
          $term->name = $keyword->name;
          $term->field_mm_display_name[LANGUAGE_NONE][0]['value'] = $keyword->display_name;
          $term->description = $keyword->description;
          $term->vid = $vocab->vid;
          taxonomy_term_save($term);
        }
      }
    }
  }

  /**
   * @param $machine_name
   *   Machine name of the target vocabulary.
   */
  private static function addDisplayName($machine_name) {

    $field_name = 'field_mm_display_name';
    if (!field_info_field($field_name)) {
      $field = array(
        'field_name' => $field_name,
        'type' => 'text',
        'label' => t('Display name'));
      field_create_field($field);
    }

    // Attach the field to our taxonomy entity
    $instance = array(
      'field_name' => 'field_mm_display_name',
      'entity_type' => 'taxonomy_term',
      'bundle' => $machine_name,
      'label' => t('Display name'),
      'description' => t('Human readable name'),
      'required' => true,
      'widget' => array(
        'type' => 'text_textfield',
        'settings'=> array(
          'max_width'=>60,
        )
      ),
    );
    field_create_instance($instance);
  }

  public static function uninstall() {
    $vocabs = taxonomy_get_vocabularies();
    foreach ($vocabs as $vid => $vocab) {
      if ($vocab->module == 'mm') {
        taxonomy_vocabulary_delete($vid);
      }
    }
  }
}
